@@ -64,6 +64,20 @@ def min_from_midnight(ts: float) -> float:
     return get_day(ts).hour * 60 + get_day(ts).minute
 
 
+def ms_from_midnight(ts: float) -> float:
+    """
+    Milliseconds passed since midnight
+    :param ts:
+    :return:
+    """
+    if ts > 5000000000:
+        ts /= 1000
+    today = datetime.datetime.fromtimestamp(ts, tz=gettz(os.environ["TZ"]))
+    mid_ts = datetime.datetime(today.year, today.month, today.day,
+                               tzinfo=gettz(os.environ['TZ'])).timestamp()
+    return (ts - mid_ts) * 1000
+
+
 def day_of_the_week(ts: float) -> str:
     """
     Returns day of the week for the ts
@@ -103,17 +117,26 @@ def tot_min() -> int:
     return hour() * 60 + minute()
 
 
-def midday_ts(days_back: int = 0) -> float:
+def midday_ts(days_back: int = 0, ts: float = 0.) -> float:
     """
     The 12:00 local time N days back
+    :param ts:
     :param days_back:
     :return: ts in ms
     """
-    today = datetime.datetime.now(gettz(os.environ['TZ']))
-    yesterday = datetime.datetime(today.year, today.month, today.day, 12,
-                                  tzinfo=gettz(os.environ['TZ'])) - \
-                datetime.timedelta(days=days_back)
-    return yesterday.timestamp() * 1000
+    if not ts:
+        today = datetime.datetime.now(gettz(os.environ['TZ']))
+        yesterday = datetime.datetime(today.year, today.month, today.day, 12,
+                                      tzinfo=gettz(os.environ['TZ'])) - \
+                    datetime.timedelta(days=days_back)
+        return yesterday.timestamp() * 1000
+    else:
+        day = datetime.datetime.fromtimestamp(ts, tz=gettz(os.environ["TZ"]))
+        return datetime.datetime(day.year,
+                                 day.month,
+                                 day.day,
+                                 12,
+                                 tzinfo=gettz(os.environ['TZ'])).timestamp() * 1000
 
 
 def midnight_ts(days_back: int = 0) -> float:
@@ -284,3 +307,23 @@ def activity_filter(ts_grid: np.array, activ_dens: np.array) -> np.array:
     """
     peak_indices, _ = find_peaks(activ_dens)
     return ts_grid[peak_indices]
+
+
+def convert_to_float(structure: dict) -> dict:
+    """
+    Convert all Decimal numbers to float
+    :param structure:
+    :return:
+    """
+    return json.loads(json.dumps(structure, cls=DecimalEncoder))
+
+
+def convert_to_decimal(structure: dict) -> dict:
+    """
+    Convert all float and int numbers to Decimal for DynamoDB compatibility
+    :param structure:
+    :return:
+    """
+    return json.loads(json.dumps(convert_to_float(structure)),
+                      parse_float=decimal.Decimal,
+                      parse_int=decimal.Decimal)
